SQLAlchemy 0.4 Documentation - module sqlalchemy.types

# SQLAlchemy 0.4 Documentation

Multiple Pages | One Page
Version: 0.4.3 Last Updated: 02/14/08 18:54:07

### module sqlalchemy.types

defines genericized SQL types, each represented by a subclass of AbstractType. Dialects define further subclasses of these types.

For more information see the SQLAlchemy documentation on types.

### class AbstractType(object)

def __init__(self, *args, **kwargs)

Construct a new `AbstractType`.

def adapt_operator(self, op)

given an operator from the sqlalchemy.sql.operators package, translate it to a new operator based on the semantics of this type.

By default, returns the operator unchanged.

def bind_processor(self, dialect)

Defines a bind parameter processing function.

def compare_values(self, x, y)

compare two values for equality.

def convert_bind_param(self, value, dialect)

Legacy convert_bind_param() compatability method.

This adapter method is provided for user-defined types that implement the older convert_* interface and need to call their super method. These calls are adapted behind the scenes to use the newer callable-based interface via bind_processor().

Compatibility is configured on a case-by-case basis at class definition time by a legacy adapter metaclass. This method is only available and functional if the concrete subclass implements the legacy interface.

def convert_result_value(self, value, dialect)

Legacy convert_result_value() compatibility method.

This adapter method is provided for user-defined types that implement the older convert_* interface and need to call their super method. These calls are adapted behind the scenes to use the newer callable-based interface via result_processor().

Compatibility is configured on a case-by-case basis at class definition time by a legacy adapter metaclass. This method is only available and functional if the concrete subclass implements the legacy interface.

def copy_value(self, value)
def get_dbapi_type(self, dbapi)

Return the corresponding type object from the underlying DB-API, if any.

This can be useful for calling `setinputsizes()`, for example.

def is_mutable(self)

return True if the target Python type is 'mutable'.

This allows systems like the ORM to know if an object can be considered 'not changed' by identity alone.

def result_processor(self, dialect)

Defines a result-column processing function.

back to section top

### class BLOB(Binary)

back to section top

### class BOOLEAN(Boolean)

back to section top

### class Binary(TypeEngine)

def __init__(self, length=None)

Construct a new `Binary`.

def adapt(self, impltype)
def bind_processor(self, dialect)
def get_dbapi_type(self, dbapi)
back to section top

### class Boolean(TypeEngine)

back to section top

### class CHAR(String)

back to section top

### class CLOB(Text)

back to section top

### class DATE(Date)

back to section top

### class DATETIME(DateTime)

back to section top

### class DECIMAL(Numeric)

back to section top

### class Date(TypeEngine)

Implement a type for `datetime.date()` objects.

def get_dbapi_type(self, dbapi)
back to section top

### class DateTime(TypeEngine)

Implement a type for `datetime.datetime()` objects.

def __init__(self, timezone=False)

Construct a new `DateTime`.

def adapt(self, impltype)
def get_dbapi_type(self, dbapi)
back to section top

### class FLOAT(Float)

back to section top

### class Float(Numeric)

def __init__(self, precision=10, asdecimal=False, **kwargs)

Construct a new `Float`.

def adapt(self, impltype)
back to section top

### class INT(Integer)

back to section top

### class Integer(TypeEngine)

Integer datatype.

def get_dbapi_type(self, dbapi)
back to section top

### class Interval(TypeDecorator)

Type to be used in Column statements to store python timedeltas.

If it's possible it uses native engine features to store timedeltas (now it's only PostgreSQL Interval type), if there is no such it fallbacks to DateTime storage with converting from/to timedelta on the fly

Converting is very simple - just use epoch(zero timestamp, 01.01.1970) as base, so if we need to store timedelta = 1 day (24 hours) in database it will be stored as DateTime = '2nd Jan 1970 00:00', see bind_processor and result_processor to actual conversion code

def bind_processor(self, dialect)
def load_dialect_impl(self, dialect)

Checks if engine has native implementation of timedelta python type, if so it returns right class to handle it, if there is no native support, it fallback to engine's DateTime implementation class

def result_processor(self, dialect)
back to section top

### class NCHAR(Unicode)

back to section top

### class NUMERIC(Numeric)

back to section top

### class Numeric(TypeEngine)

Numeric datatype, usually resolves to DECIMAL or NUMERIC.

def __init__(self, precision=10, length=2, asdecimal=True)

Construct a new `Numeric`.

def adapt(self, impltype)
def bind_processor(self, dialect)
def get_dbapi_type(self, dbapi)
def result_processor(self, dialect)
back to section top

### class PickleType(MutableType,TypeDecorator)

def __init__(self, protocol=2, pickler=None, mutable=True, comparator=None)

Construct a new `PickleType`.

def bind_processor(self, dialect)
def compare_values(self, x, y)
def copy_value(self, value)
def is_mutable(self)
def result_processor(self, dialect)
back to section top

### class SMALLINT(SmallInteger)

back to section top

### class SmallInteger(Integer)

Smallint datatype.

back to section top

### class String(Concatenable,TypeEngine)

A sized string type.

Usually corresponds to VARCHAR. Can also take Python unicode objects and encode to the database's encoding in bind params (and the reverse for result sets.)

a String with no length will adapt itself automatically to a Text object at the dialect level (this behavior is deprecated in 0.4).

def __init__(self, length=None, convert_unicode=False, assert_unicode=None)

Construct a new `String`.

def adapt(self, impltype)
def bind_processor(self, dialect)
def dialect_impl(self, dialect, **kwargs)
def get_dbapi_type(self, dbapi)
def get_search_list(self)
def result_processor(self, dialect)
back to section top

### class TIME(Time)

back to section top

### class TIMESTAMP(DateTime)

back to section top

### class Text(String)

def dialect_impl(self, dialect, **kwargs)
back to section top

### class Time(TypeEngine)

Implement a type for `datetime.time()` objects.

def __init__(self, timezone=False)

Construct a new `Time`.

def adapt(self, impltype)
def get_dbapi_type(self, dbapi)
back to section top

### class TypeDecorator(AbstractType)

def __init__(self, *args, **kwargs)

Construct a new `TypeDecorator`.

def bind_processor(self, dialect)
def compare_values(self, x, y)
def copy(self)
def copy_value(self, value)
def dialect_impl(self, dialect, **kwargs)
def get_col_spec(self)
def get_dbapi_type(self, dbapi)
def is_mutable(self)
def load_dialect_impl(self, dialect)

loads the dialect-specific implementation of this type.

by default calls dialect.type_descriptor(self.impl), but can be overridden to provide different behavior.

def process_bind_param(self, value, dialect)
def process_result_value(self, value, dialect)
def result_processor(self, dialect)
def __getattr__(self, key)

Proxy all other undefined accessors to the underlying implementation.

back to section top

### class TypeEngine(AbstractType)

def adapt(self, cls)
def bind_processor(self, dialect)
def dialect_impl(self, dialect, **kwargs)
def get_col_spec(self)
def get_search_list(self)

return a list of classes to test for a match when adapting this type to a dialect-specific type.

def result_processor(self, dialect)
back to section top

### class Unicode(String)

A synonym for String(length, convert_unicode=True, assert_unicode='warn').

def __init__(self, length=None, **kwargs)

Construct a new `Unicode`.

back to section top

### class UnicodeText(Text)

A synonym for Text(convert_unicode=True, assert_unicode='warn').

def __init__(self, length=None, **kwargs)

Construct a new `UnicodeText`.

back to section top

### class VARCHAR(String)

back to section top